==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkSelectVisiblePoints.java <==
// java wrapper for vtkSelectVisiblePoints object
//

package vtk;
import vtk.*;

public class vtkSelectVisiblePoints extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRenderer_2(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_2(id0); }

  private native long GetRenderer_3();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_3();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSelectionWindow_4(int id0);
  public void SetSelectionWindow(int id0)
    { SetSelectionWindow_4(id0); }

  private native int GetSelectionWindow_5();
  public int GetSelectionWindow()
    { return GetSelectionWindow_5(); }

  private native void SelectionWindowOn_6();
  public void SelectionWindowOn()
    { SelectionWindowOn_6(); }

  private native void SelectionWindowOff_7();
  public void SelectionWindowOff()
    { SelectionWindowOff_7(); }

  private native void SetSelection_8(int id0,int id1,int id2,int id3);
  public void SetSelection(int id0,int id1,int id2,int id3)
    { SetSelection_8(id0,id1,id2,id3); }

  private native void SetSelection_9(int id0[]);
  public void SetSelection(int id0[])
    { SetSelection_9(id0); }

  private native int[]  GetSelection_10();
  public int[]  GetSelection()
    { return GetSelection_10(); }

  private native void SetSelectInvisible_11(int id0);
  public void SetSelectInvisible(int id0)
    { SetSelectInvisible_11(id0); }

  private native int GetSelectInvisible_12();
  public int GetSelectInvisible()
    { return GetSelectInvisible_12(); }

  private native void SelectInvisibleOn_13();
  public void SelectInvisibleOn()
    { SelectInvisibleOn_13(); }

  private native void SelectInvisibleOff_14();
  public void SelectInvisibleOff()
    { SelectInvisibleOff_14(); }

  private native void SetTolerance_15(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_15(id0); }

  private native double GetToleranceMinValue_16();
  public double GetToleranceMinValue()
    { return GetToleranceMinValue_16(); }

  private native double GetToleranceMaxValue_17();
  public double GetToleranceMaxValue()
    { return GetToleranceMaxValue_17(); }

  private native double GetTolerance_18();
  public double GetTolerance()
    { return GetTolerance_18(); }

  private native int GetMTime_19();
  public int GetMTime()
    { return GetMTime_19(); }

  public vtkSelectVisiblePoints() { super(); }

  public vtkSelectVisiblePoints(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkSelectVisiblePoints.java <==
// java wrapper for vtkSelectVisiblePoints object
//

package vtk;
import vtk.*;

public class vtkSelectVisiblePoints extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRenderer_2(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_2(id0); }

  private native long GetRenderer_3();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_3();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSelectionWindow_4(int id0);
  public void SetSelectionWindow(int id0)
    { SetSelectionWindow_4(id0); }

  private native int GetSelectionWindow_5();
  public int GetSelectionWindow()
    { return GetSelectionWindow_5(); }

  private native void SelectionWindowOn_6();
  public void SelectionWindowOn()
    { SelectionWindowOn_6(); }

  private native void SelectionWindowOff_7();
  public void SelectionWindowOff()
    { SelectionWindowOff_7(); }

  private native void SetSelection_8(int id0,int id1,int id2,int id3);
  public void SetSelection(int id0,int id1,int id2,int id3)
    { SetSelection_8(id0,id1,id2,id3); }

  private native void SetSelection_9(int id0[]);
  public void SetSelection(int id0[])
    { SetSelection_9(id0); }

  private native int[]  GetSelection_10();
  public int[]  GetSelection()
    { return GetSelection_10(); }

  private native void SetSelectInvisible_11(int id0);
  public void SetSelectInvisible(int id0)
    { SetSelectInvisible_11(id0); }

  private native int GetSelectInvisible_12();
  public int GetSelectInvisible()
    { return GetSelectInvisible_12(); }

  private native void SelectInvisibleOn_13();
  public void SelectInvisibleOn()
    { SelectInvisibleOn_13(); }

  private native void SelectInvisibleOff_14();
  public void SelectInvisibleOff()
    { SelectInvisibleOff_14(); }

  private native void SetTolerance_15(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_15(id0); }

  private native double GetToleranceMinValue_16();
  public double GetToleranceMinValue()
    { return GetToleranceMinValue_16(); }

  private native double GetToleranceMaxValue_17();
  public double GetToleranceMaxValue()
    { return GetToleranceMaxValue_17(); }

  private native double GetTolerance_18();
  public double GetTolerance()
    { return GetTolerance_18(); }

  private native int GetMTime_19();
  public int GetMTime()
    { return GetMTime_19(); }

  public vtkSelectVisiblePoints() { super(); }

  public vtkSelectVisiblePoints(long id) { super(id); }
  public native long   VTKInit();

}
